pub struct StatType<R: RegistryExt> {
pub key: Identifier,
stat_type_entry_ref: OnceLock<StatTypeEntryRef>,
_phantom: PhantomData<R>,
}Expand description
A structure that identifies a type of stat, using the
registry type [R] for using items from it to identify a particular stat.
Fields
key: IdentifierThe identifier that identifies this stat type uniquely.
stat_type_entry_ref: OnceLock<StatTypeEntryRef>_phantom: PhantomData<R>Implementations
Sourceimpl<R: RegistryExt> StatType<R>where
R::Entry: StatValueRegistryEntry,
impl<R: RegistryExt> StatType<R>where
R::Entry: StatValueRegistryEntry,
Sourcepub(crate) const fn new(key: Identifier) -> Self
pub(crate) const fn new(key: Identifier) -> Self
Creates a new StatType from a key and its display name.
Sourcepub const fn key(&self) -> &Identifier
pub const fn key(&self) -> &Identifier
Returns the identifying key of this stat type.
Sourcepub fn stat_type_entry_ref(&self) -> StatTypeEntryRef
pub fn stat_type_entry_ref(&self) -> StatTypeEntryRef
Gets the reference to the entry corresponding to their stat type.
Panics
Panics if this stat type has not been registered with the StatTypeRegistry.