StatTypeEntry

Struct StatTypeEntry 

pub struct StatTypeEntry {
    pub key: Identifier,
    registry: LazyLock<StatValueRegistryData, Box<dyn FnOnce() -> StatValueRegistryData + Send + Sync>>,
}
An entry stored in the stat type registry. It represents a stat type.

A stat type is always associated with a registry whose values will be used to identify stats from this stat type. Therefore, StatTypeEntry contains the registry responsible for the encoding and decoding of the values involved.

For example, ITEM_DROPPED uses the item registry to have each item in this registry become a stat under this stat type (like diamond) to track how many of those items have been dropped by the player.

Internally, the registry is stored in a LazyLock, so that the reference to the registry is only loaded after it has initialized.

Fields

key: Identifier

The identifier of this stat type.

registry: LazyLock<StatValueRegistryData, Box<dyn FnOnce() -> StatValueRegistryData + Send + Sync>>

The registry that can encode and decode the stat identity involved in this stat type.

Implementations

Source

impl StatTypeEntry

pub fn registry_len(&self) -> usize

Gets the number of entries in this registry that this stat type is associated with.

pub fn key_from_id(&self, id: usize) -> Option<&Identifier>

Gets the key of an item in this registry by its registry ID.

pub fn id_from_key(&self, key: &Identifier) -> Option<usize>

Gets the registry ID of an item in this registry by its key.

pub fn value_from_id( &self, id: usize, ) -> Option<&'static dyn StatValueRegistryEntry>

Gets the erased value of an item in this registry by its registry ID.

pub fn value_from_key( &self, key: &Identifier, ) -> Option<&'static dyn StatValueRegistryEntry>

Gets the erased value of an item in this registry by its key.