pub struct StatTypeRegistry {
stat_types_by_id: Vec<StatTypeEntryRef>,
stat_types_by_key: FxHashMap<Identifier, usize>,
allows_registering: bool,
}Expand description
Registry of all stat types. A stat type is always associated with a registry whose values will be used to identify stats from this stat type.
For example, ITEM_DROPPED uses the item registry to have each item in this registry become a stat
under this stat type (like diamond) to track how many of those items have been dropped by the player.
Fields
stat_types_by_id: Vec<StatTypeEntryRef>Stat types indexed by network ID.
stat_types_by_key: FxHashMap<Identifier, usize>Map which maps from the stat type identifier to its network ID.
allows_registering: boolWhether registration is still allowed.
Implementations
Sourceimpl StatTypeRegistry
impl StatTypeRegistry
Sourcepub fn register<R, F>(
&mut self,
stat_type: StatTypeRef<R>,
registry_supplier: F,
)
pub fn register<R, F>( &mut self, stat_type: StatTypeRef<R>, registry_supplier: F, )
Registers a stat type in this registry.
The registry supplied in this function must be in a supplier so that it only runs once when the registries are initialized.
Sourcepub fn iter(&self) -> impl Iterator<Item = (usize, StatTypeEntryRef)> + '_
pub fn iter(&self) -> impl Iterator<Item = (usize, StatTypeEntryRef)> + '_
Iterates all stat type entries in this registry.