pub trait StatValueRegistryEntry:
Send
+ Sync
+ 'static {
// Required methods
fn stat_value_key(&self) -> &Identifier;
fn stat_value_id(&self) -> usize;
}Expand description
Behavior required for a registry entry so that it can be used for identifying a particular stat.
Required Methods
fn stat_value_key(&self) -> &Identifier
fn stat_value_id(&self) -> usize
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".